@@ -1,4 +1,4 @@
-#VERSION: 1.44
+#VERSION: 1.45
 
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are met:
@@ -24,43 +24,40 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-
 def prettyPrinter(dictionary):
-	outtext = ''
-	dictionary['size'] = anySizeToBytes(dictionary['size'])
-	if 'desc_link' in dictionary:
-		outtext = '%s|%s|%s|%s|%s|%s|%s'%(dictionary['link'],dictionary['name'].replace('|',' '),dictionary['size'],dictionary['seeds'],dictionary['leech'],dictionary['engine_url'],dictionary['desc_link'])
-	else:
-		outtext = '%s|%s|%s|%s|%s|%s'%(dictionary['link'],dictionary['name'].replace('|',' '),dictionary['size'],dictionary['seeds'],dictionary['leech'],dictionary['engine_url'])
+    dictionary['size'] = anySizeToBytes(dictionary['size'])
+    outtext = "|".join((dictionary["link"], dictionary["name"].replace("|", " "), str(dictionary["size"]), str(dictionary["seeds"]), str(dictionary["leech"]), dictionary["engine_url"]))
+    if 'desc_link' in dictionary:
+        outtext = "|".join((outtext, dictionary["desc_link"]))
 
-	# fd 1 is stdout
-	with open(1, 'w', encoding='utf-8', closefd=False) as utf8stdout:
-		print(outtext, file=utf8stdout)
+    # fd 1 is stdout
+    with open(1, 'w', encoding='utf-8', closefd=False) as utf8stdout:
+        print(outtext, file=utf8stdout)
 
 def anySizeToBytes(size_string):
-	"""
-	Convert a string like '1 KB' to '1024' (bytes)
-	"""
-	# separate integer from unit
-	try:
-		size, unit = size_string.split()
-	except:
-		try:
-			size = size_string.strip()
-			unit = ''.join([c for c in size if c.isalpha()])
-			if len(unit) > 0:
-				size = size[:-len(unit)]
-		except:
-			return -1
-	if len(size) == 0:
-		return -1
-	size = float(size)
-	if len(unit) == 0:
-		return int(size)
-	short_unit = unit.upper()[0]
+    """
+    Convert a string like '1 KB' to '1024' (bytes)
+    """
+    # separate integer from unit
+    try:
+        size, unit = size_string.split()
+    except:
+        try:
+            size = size_string.strip()
+            unit = ''.join([c for c in size if c.isalpha()])
+            if len(unit) > 0:
+                size = size[:-len(unit)]
+        except:
+            return -1
+    if len(size) == 0:
+        return -1
+    size = float(size)
+    if len(unit) == 0:
+        return int(size)
+    short_unit = unit.upper()[0]
 
-	# convert
-	units_dict = { 'T': 40, 'G': 30, 'M': 20, 'K': 10 }
-	if short_unit in units_dict:
-		size = size * 2**units_dict[short_unit]
-	return int(size)
+    # convert
+    units_dict = {'T': 40, 'G': 30, 'M': 20, 'K': 10}
+    if short_unit in units_dict:
+        size = size * 2**units_dict[short_unit]
+    return int(size)
