@@ -33,19 +33,27 @@
 
 #include <QCoreApplication>
 #include <QString>
+#include <QVariant>
 
-class btjson {
-  Q_DECLARE_TR_FUNCTIONS(misc)
+class QTorrentHandle;
+
+class btjson
+{
+    Q_DECLARE_TR_FUNCTIONS(misc)
 
 private:
-  btjson() {}
+    btjson() {}
 
 public:
-  static QByteArray getTorrents();
-  static QByteArray getTrackersForTorrent(const QString& hash);
-  static QByteArray getPropertiesForTorrent(const QString& hash);
-  static QByteArray getFilesForTorrent(const QString& hash);
-  static QByteArray getTransferInfo();
+    static QByteArray getTorrents(QString filter = "all", QString label = QString(),
+        QString sortedColumn = "name", bool reverse = false, int limit = 0, int offset = 0);
+    static QByteArray getSyncMainData(int acceptedResponseId, QVariantMap &lastData, QVariantMap &lastAcceptedData);
+    static QByteArray getTrackersForTorrent(const QString& hash);
+    static QByteArray getWebSeedsForTorrent(const QString& hash);
+    static QByteArray getPropertiesForTorrent(const QString& hash);
+    static QByteArray getFilesForTorrent(const QString& hash);
+    static QByteArray getTransferInfo();
+    static QByteArray getTorrentsRatesLimits(QStringList& hashes, bool downloadLimits);
 }; // class btjson
 
 #endif // BTJSON_H
